#!/usr/bin/env python
import os
import sys


def add_debug_apps():

    """
        Para que se pueda estar depurando una aplicacion
        sin instalar la aplicacion realmente app como microsip_api.
    """
    REPOSITORIES_PATH = str(os.path.abspath(__file__ + "/../../../"))

    # ADD API
    new_path = "{}\{}".format(REPOSITORIES_PATH, 'django-microsip-api')
    print (new_path)
    sys.path.append(new_path)

    # ADD APPS
    DJMICROSIP_APPS = str(os.path.join(REPOSITORIES_PATH, 'djmicrosip_apps'))
    debug_apps = []
    #obtenemos las carpetas que esten en DJMICROSIP_APPS
    debug_apps = os.listdir(DJMICROSIP_APPS)
    for debug_app in debug_apps:
        new_path = "{}\{}".format(DJMICROSIP_APPS, debug_app)
        sys.path.append(new_path)

# Para poder depurar aplicaciones sin isntalar
add_debug_apps()

if __name__ == "__main__":
    os.environ.setdefault("DJANGO_SETTINGS_MODULE", "django_microsip_base.settings.dev_plus")

    from django.core.management import execute_from_command_line

    execute_from_command_line(sys.argv)



import compileall, os
BASE_DIR = os.path.dirname(os.path.dirname(__file__))
dirs =  [
	BASE_DIR +"\\django_microsip_base\\apps\\main",
	BASE_DIR +"\\django_microsip_base\\data",
	BASE_DIR +"\\django_microsip_base\\libs",
	BASE_DIR +"\\django_microsip_base\\settings",
	BASE_DIR +"\\django_microsip_base\\urls",
	BASE_DIR +"\\django_microsip_base\\con",
]

for directorio in dirs:
	compileall.compile_dir(directorio, force=True)
	
compileall.compile_file(BASE_DIR +"\\django_microsip_base\\context_processors.py")




from dev import *
import os

TEST_DB = 'AD2007'
SYSDBA_PWD = '1'

DATABASE_ROUTERS = ['django_microsip_base.libs.databases_routers_tests.MainRouter']

# Test runner with no database creation
TEST_RUNNER = 'django_microsip_base.runner.NoDbTestRunner'

MICROSIP_DATOS_PATH = os.environ['MICROSIP_DATOS_PATH']
MICROSIP_DATABASES = {}
user = 'SYSDBA'
password = '1'
host = '127.0.0.1'
DATABASES = {
    'default': {
        'ENGINE': 'django.db.backends.sqlite3',
        'NAME':  os.path.join(MICROSIP_DATOS_PATH, 'System', 'U.sqlite3'),
        'USER': '',
        'PASSWORD': '',
        'HOST': '',
        'PORT': '',
        'ATOMIC_REQUESTS': True,
    },
}

DATABASES['01-CONFIG'] = {
    'ENGINE': 'firebird',
    'NAME': '%s\System\CONFIG.FDB' % MICROSIP_DATOS_PATH,
    'USER': user,
    'PASSWORD': password,
    'HOST': host,
    'PORT': '3050',
    'OPTIONS': {'charset': 'ISO8859_1'},
    'ATOMIC_REQUESTS': True,
}

DATABASES['01-METADATOS'] = {
    'ENGINE': 'firebird',
    'NAME': '%s\System\Metadatos.fdb' % MICROSIP_DATOS_PATH,
    'USER': user,
    'PASSWORD': password,
    'HOST': host,
    'PORT': '3050',
    'OPTIONS': {'charset': 'ISO8859_1'},
    'ATOMIC_REQUESTS': True,
}

DATABASES['01-%s' % TEST_DB] = {
    'ENGINE': 'firebird',
    'NAME': '%s\%s.fdb' % (MICROSIP_DATOS_PATH, TEST_DB),
    'USER': user,
    'PASSWORD': password,
    'HOST': host,
    'PORT': '3050',
    'OPTIONS': {'charset': 'ISO8859_1'},
    'ATOMIC_REQUESTS': True,
}

MICROSIP_DATABASES['01-%s' % TEST_DB] = {
    'ENGINE': 'firebird',
    'NAME': name,
    'USER': user,
    'PASSWORD': password,
    'HOST': host,
    'PORT': '3050',
    'OPTIONS': {'charset': 'ISO8859_1'},
    'ATOMIC_REQUESTS': True,
}

ROOT_URLCONF = 'django_microsip_base.urls.dev'
MICROSIP_VERSION = 2015



from django.test.simple import DjangoTestSuiteRunner


class NoDbTestRunner(DjangoTestSuiteRunner):
    """ A test runner to test without database creation """
    def setup_databases(self, **kwargs):
        """ Override the database creation defined in parent class """
        pass

    def teardown_databases(self, old_config, **kwargs):
        """ Override the database teardown defined in parent class """
        pass



from .common import *

DEBUG = True
TEMPLATE_DEBUG = DEBUG
MODO_SERVIDOR = 'PRUEBAS'
MICROSIP_VERSION = '2017'
EXTRA_MODULES = (
    # 'django-microsip-cancela-cfdi',
    # 'django-microsip-consolidador',
    # 'django-microsip-liquida',
    # 'django-microsip-quickbooks',
    # 'django-microsip-ventas-remgencargos',
    # 'django_microsip_catalogoarticulos',
    # 'django_microsip_catalogoprod',
    # 'django_microsip_consultaprecio',
    # 'django_microsip_diot',
    # 'django_microsip_exporta_xml',
    # 'django_microsip_exportaexcel',
    # 'django_msp_controldeacceso',
    # 'django_msp_facturaglobal',
    # 'django_msp_importa_inventario',
    # 'django_msp_sms',
    # 'djmicrosip_actualizarcosto',
    # 'djmicrosip_auditacotizacion',
    # 'djmicrosip_cambiaprecio_sincosto',
    # 'djmicrosip_cambiaprecios',
    # 'djmicrosip_cargos_cxp',
    # 'djmicrosip_cotizador',
    # 'djmicrosip_cotizadormovil',
    # 'djmicrosip_exportadb',
    # 'djmicrosip_exportaimportaprecios',
    # 'djmicrosip_faexist',
    # 'djmicrosip_facturacion',
    # 'djmicrosip_inventarios',
    # 'djmicrosip_mail',
    # 'djmicrosip_comparadb',
    # 'djmicrosip_mensajesdocumentos',
    # 'djmicrosip_organizador',
    # 'djmicrosip_polizas',
    # 'djmicrosip_polizasautomaticas',
    # 'djmicrosip_puntos',
    # 'djmicrosip_remgencargos',
    # 'djmicrosip_reorden',
    # 'djmicrosip_reportes',
    # 'djmicrosip_generareorden',
    # 'djmicrosip_generaventasconsig',
    # 'djmicrosip_tareas',
    # 'djmicrosip_traspasofacturas',
    # 'djmicrosip_utilerias',
    # 'djmicrosip_utilerias',
    # 'djmicrosip_generareorden',
)

DJANGO_APPS += (
    'django_extensions',
    'werkzeug_debugger_runserver',
)


from .common import get_microsip_extra_apps
MICROSIP_EXTRA_APPS, EXTRA_APPS = get_microsip_extra_apps(EXTRA_MODULES, is_dev=True)
INSTALLED_APPS = DJANGO_APPS + MICROSIP_MODULES + MICROSIP_EXTRA_APPS

ROOT_URLCONF = 'django_microsip_base.urls.dev'

# Additional locations of static files
STATICFILES_DIRS = (
    (BASE_DIR + '/static/'),
)



import autocomplete_light.shortcuts as autocomplete_light
from django.conf.urls.static import static
autocomplete_light.autodiscover()

#from django.conf.urls import  include, url
from django.urls import include, path,re_path
from django.contrib.staticfiles.urls import staticfiles_urlpatterns

from django.conf import settings

urlpatterns = [
    path('', include('django_microsip_base.apps.main.urls')),
    path('', include('microsip_api.apps.config.urls')),
    path('administrador/', include('microsip_api.apps.administrador.urls')),
    path('autocomplete/', include('autocomplete_light.urls')),
    # path("select2/", include("django_select2.urls")),
    # path('media/<string:path>', include('django.views.static.serve'),
    #     {'document_root': settings.MEDIA_ROOT, }),
]+ static(settings.MEDIA_URL, document_root=settings.MEDIA_ROOT)

# static(settings.MEDIA_URL, document_root=settings.MEDIA_ROOT)
for plugin in settings.EXTRA_APPS:
    urlpatterns += path(''+plugin['url_main_path'], include(plugin['app']+'.urls')),


urlpatterns += staticfiles_urlpatterns()



from django.conf import settings
import importlib

def menu(request):
    context = {'menu':[]}
    selected_app = 'Inicio'
    items=[]

    if '/administrador/' in request.path:
        selected_app = 'Administrador'
    else:
        for app in settings.EXTRA_APPS:
            if app['url_main_path'] in request.path:
                selected_app = app['name']
    
    context_menu = {
        'name': selected_app,
        'selected_app':selected_app,
        'icon_class':'glyphicon glyphicon-home',
        'items':items,
    }
    for app in settings.EXTRA_APPS:
        if request.user.username in app['users'] or not app['users']:
            context_menu['items'].append({'name':app['name'], 'url':app['url'], 'icon_class':app['icon_class'],})
    
    context['menu']=context_menu
    
    return context


from .common import *
import os

DEBUG = True
ALLOWED_HOSTS = ['*', ]
TEMPLATE_DEBUG = DEBUG
MODO_SERVIDOR = 'PROD'

extra_list = os.environ['SIC_INSTALLED_APPS'].split(',')
extra_list.remove('')
EXTRA_MODULES = tuple(extra_list)

MICROSIP_VERSION = os.environ['MICROSIP_VERSION']

from .common import get_microsip_extra_apps
MICROSIP_EXTRA_APPS, EXTRA_APPS = get_microsip_extra_apps(EXTRA_MODULES)

INSTALLED_APPS = DJANGO_APPS + MICROSIP_MODULES + tuple(MICROSIP_EXTRA_APPS)

ROOT_URLCONF = 'django_microsip_base.urls.prod'

import djcelery
djcelery.setup_loader()

BROKER_URL = 'redis://localhost:6379/0'

# Additional locations of static files
STATICFILES_DIRS = (
    (BASE_DIR + '/static/'),
)



import os
import compileall
import sys

from setuptools import setup, find_packages
import pathlib

if "sdist" in sys.argv:
    path = os.path.abspath(os.path.dirname(__file__))+"\\django_microsip_base\\"
    compileall.compile_dir(path, force=True)

# with open(os.path.join(os.path.dirname(__file__), 'README.rst')) as readme:
#     README = readme.read()
here = pathlib.Path(__file__).parent.resolve()
long_description = (here / 'README.rst').read_text(encoding='utf-8')
# this grabs the requirements from requirements.txt
REQUIREMENTS = [i.strip() for i in open("requirements.txt").readlines()]
# allow setup.py to be run from any path
os.chdir(os.path.normpath(os.path.join(os.path.abspath(__file__), os.pardir)))

setup(
    name='django-microsip-base',
    version='1.3.5',
    packages=find_packages(),
    include_package_data=True,
    description="Django Microsip Base",
    long_description=long_description,
    long_description_content_type='text/markdown',
    author="Servicios de Ingenieria Computacional",
    author_email="desarrollo@siccomputacion.com",
    url = '',   
    classifiers=[
        'Environment :: Web Environment',
        'Framework :: Django',
        'Intended Audience :: Developers',
        'Operating System :: OS Independent',
        'Topic :: Software Development :: Build Tools',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
    ],
    install_requires=REQUIREMENTS,
)



#encoding:utf-8
import django.contrib.humanize
# Identificando la ruta del proyecto
import os
import fdb
import sqlite3
import socket
from uuid import getnode as get_mac

def get_microsip_extra_apps(EXTRA_MODULES, is_dev= False):
    allowed_apps = []
    import importlib, sys
    EXTRA_APPS = []
    sic_password = os.getenv('SIC_PASSWORD')
    from microsip_api.core.crypt import EncoderSIC
    enc = EncoderSIC()
    if not is_dev:
        value = enc.decrypt(sic_password)
        allowed_apps = value.split('|')[1].split(',')
    
    for module in EXTRA_MODULES:
        if module in allowed_apps or is_dev:
            try:
                module_config = importlib.import_module(module+'.config')
            except ImportError as exc:
                sys.stderr.write("Error: failed to import settings module ({})".format(exc))
            else:
                module_settings = module_config.settings

                EXTRA_APPS.append({
                    'app': module,
                    'name': module_settings['name'],
                    'icon_class':module_settings['icon_class'],
                    'url':module_settings['url'],
                    'url_main_path':module_settings['url_main_path'],
                    'users':module_settings['users'],
                    }
                )

    MICROSIP_EXTRA_APPS = ()
    
    for microsip_app in EXTRA_APPS:
        MICROSIP_EXTRA_APPS += (microsip_app['app'],)

    return MICROSIP_EXTRA_APPS, EXTRA_APPS
    

EXTRA_INFO = {
    'ruta_datos_facturacion': 'C:\sat',
}

DJANGO_APPS = (
    'django.contrib.auth',
    'django.contrib.contenttypes',
    'django.contrib.sessions',
    'django.contrib.sites',
    'django.contrib.messages',
    'django.contrib.staticfiles',
    'django.contrib.admin',
    'django.contrib.humanize',
    'autocomplete_light',
    'djcelery',
    'multiselectfield',
    'xhtml2pdf',
)

MICROSIP_MODULES = (
    'django_microsip_base.libs.models_base',
    'microsip_api.apps.config',
    'microsip_api.apps.metadatos',
    'microsip_api.apps.administrador',
    'django_microsip_base.apps.main',
)

# FORM_RENDERER = 'django.forms.renderers.DjangoTemplates'

BASE_DIR = os.path.dirname(os.path.dirname(__file__))
print(BASE_DIR)
ADMINS = (
    # ('Your Name', 'your_email@example.com'),
)

MICROSIP_DATOS_PATH = os.environ['MICROSIP_DATOS_PATH']
MANAGERS = ADMINS
DATABASE_ROUTERS = ['django_microsip_base.libs.databases_routers.MainRouter']
MICROSIP_DATABASES = {}
DATABASES = {
    'default': {
        'ENGINE': 'django.db.backends.sqlite3', # Add 'postgresql_psycopg2', 'mysql', 'sqlite3' or 'oracle'.
        'NAME':  os.path.join(MICROSIP_DATOS_PATH, 'System' ,'U.sqlite3'),
        'USER': '',                      # Not used with sqlite3.
        'PASSWORD': '',                  # Not used with sqlite3.
        'HOST': '',                      # Set to empty string for localhost. Not used with sqlite3.
        'PORT': '',                      # Set to empty string for default. Not used with sqlite3.
        'ATOMIC_REQUESTS': True,
    },
}
try:
    users_conn = sqlite3.connect(os.path.join(MICROSIP_DATOS_PATH, 'System' ,'U.sqlite3'))
    users_cur = users_conn.cursor()
    users_cur.execute('''SELECT * FROM auth_conexiondb''')
    conexiones_rows = users_cur.fetchall()
    users_conn.close()

    for conexion in conexiones_rows:
        
        conexion_id = conexion[0]
        conexion_id = "%02d" % conexion_id
        host = conexion[3]
        password = conexion[6]
        user = conexion[5]
        carpeta_datos = conexion[4]
        conexion_exitosa = True
        try:
            db= fdb.connect(host=host, user=user, password=password, database="%s\System\CONFIG.FDB"%carpeta_datos )
        except fdb.DatabaseError:
            conexion_exitosa = False
        else:
            cur = db.cursor()
            cur.execute("SELECT NOMBRE_CORTO FROM EMPRESAS")
            empresas_rows = cur.fetchall()
            db.close()
        
        if conexion_exitosa:

            DATABASES[ '%s-CONFIG'%conexion_id ] = {
                'ENGINE': 'firebird', # Add 'postgresql_psycopg2', 'mysql', 'sqlite3' or 'oracle'.
                'NAME': '%s\System\CONFIG.FDB'% carpeta_datos,
                'USER': user,                      # Not used with sqlite3.
                'PASSWORD': password,                  # Not used with sqlite3.
                'HOST': host,                      # Set to empty string for localhost. Not used with sqlite3.
                'PORT': '3050',                      # Set to empty string for default. Not used with sqlite3.
                'OPTIONS' : {'charset':'ISO8859_1'},
                'ATOMIC_REQUESTS': True,
            }

            DATABASES[ '%s-METADATOS'%conexion_id ] = {
                'ENGINE': 'firebird', # Add 'postgresql_psycopg2', 'mysql', 'sqlite3' or 'oracle'.
                'NAME': '%s\System\Metadatos.fdb'% carpeta_datos,
                'USER': user,                      # Not used with sqlite3.
                'PASSWORD': password,                  # Not used with sqlite3.
                'HOST': host,                      # Set to empty string for localhost. Not used with sqlite3.
                'PORT': '3050',                      # Set to empty string for default. Not used with sqlite3.
                'OPTIONS' : {'charset':'ISO8859_1'},
                'ATOMIC_REQUESTS': True,
            }

            for empresa in empresas_rows:                
                try:
                    name = '%s\%s.FDB'% (carpeta_datos, empresa[0])
                except UnicodeDecodeError:
                    pass
                else:
                    MICROSIP_DATABASES['%s-%s'%(conexion_id, empresa[0].replace(' ','_'))] = {
                        'ENGINE': 'firebird', # Add 'postgresql_psycopg2', 'mysql', 'sqlite3' or 'oracle'.
                        'NAME': name,
                        'USER': user,                      # Not used with sqlite3.
                        'PASSWORD': password,                  # Not used with sqlite3.
                        'HOST': host,                      # Set to empty string for localhost. Not used with sqlite3.
                        'PORT': '3050',                      # Set to empty string for default. Not used with sqlite3.
                        'OPTIONS' : {'charset':'ISO8859_1'},
                        'ATOMIC_REQUESTS': True,
                    }

                    DATABASES['%s-%s'%(conexion_id, empresa[0].replace(' ','_'))] = {
                        'ENGINE': 'firebird', # Add 'postgresql_psycopg2', 'mysql', 'sqlite3' or 'oracle'.
                        'NAME': name,
                        'USER': user,                      # Not used with sqlite3.
                        'PASSWORD': password,                  # Not used with sqlite3.
                        'HOST': host,                      # Set to empty string for localhost. Not used with sqlite3.
                        'PORT': '3050',                      # Set to empty string for default. Not used with sqlite3.
                        'OPTIONS' : {'charset':'ISO8859_1'},
                        'ATOMIC_REQUESTS': True,
                    }

            
except Exception as e:
    print( "Error %s:" % e.args[0])

# Local time zone for this installation. Choices can be found here:
# http://en.wikipedia.org/wiki/List_of_tz_zones_by_name
# although not all choices may be available on all operating systems.
# In a Windows environment this must be set to your system time zone.
TIME_ZONE = 'America/Mazatlan'

# Language code for this installation. All choices can be found here:
# http://www.i18nguy.com/unicode/language-identifiers.html
LANGUAGE_CODE = 'es-mx'

SITE_ID = 1

# If you set this to False, Django will make some optimizations so as not
# to load the internationalization machinery.
USE_I18N = True

# If you set this to False, Django will not format dates, numbers and
# calendars according to the current locale.
USE_L10N = True

# If you set this to False, Django will not use timezone-aware datetimes.
USE_TZ = False

# Absolute filesystem path to the directory that will hold user-uploaded files.
# Example: "/home/media/media.lawrence.com/media/"
#MEDIA_ROOT = ''

# URL that handles the media served from MEDIA_ROOT. Make sure to use a
# trailing slash.
# Examples: "http://media.lawrence.com/media/", "http://example.com/media/"
MEDIA_ROOT = os.path.join(BASE_DIR, 'media')
# os.path.join(BASE_DIR,'media' 
# Absolute path to the directory static files should be collected to.
# Don't put anything in this directory yourself; store your static files
# in apps' "static/" subdirectories and in STATICFILES_DIRS.
# Example: "/home/media/media.lawrence.com/static/"

import socket
s = socket.socket(socket.AF_INET, socket.SOCK_DGRAM)
try:
    s.connect(('google.com', 0))
except:
    ip  = '127.0.0.1'
else:
    ip = s.getsockname()[0]
nombre_equipo = socket.gethostname()
direccion_equipo = socket.gethostbyname(nombre_equipo)

ALLOWED_HOSTS = [ip,'127.0.0.1']

MEDIA_URL = '/media/'

# URL prefix for static files.
# Example: "http://media.lawrence.com/static/"
STATIC_URL = '/static/'

PDF = os.path.join(BASE_DIR, 'static')

# Additional locations of static files
STATICFILES_DIRS = (
    # Put strings here, like "/home/html/static" or "C:/www/django/static".
    # Always use forward slashes, even on Windows.
    # Don't forget to use absolute paths, not relative paths.
)

# List of finder classes that know how to find static files in
# various locations.
STATICFILES_FINDERS = (
    'django.contrib.staticfiles.finders.FileSystemFinder',
    'django.contrib.staticfiles.finders.AppDirectoriesFinder',
    'dajaxice.finders.DajaxiceFinder',
#    'django.contrib.staticfiles.finders.DefaultStorageFinder',

)


# Make this unique, and don't share it with anybody.
SECRET_KEY = '95q^soklxvniuk3(numzeb4-kbq2&h!iu1i195vj^xk2znx9ms'

# CACHES = {
#     # … default cache config and others
#     "default": {
#         "BACKEND": "django_redis.cache.RedisCache",
#         "LOCATION": "redis://127.0.0.1:6379/1",
#         "OPTIONS": {
#             "CLIENT_CLASS": "django_redis.client.DefaultClient",
#         }
#     },
#     "select2": {
#         "BACKEND": "django_redis.cache.RedisCache",
#         "LOCATION": "redis://127.0.0.1:6379/2",
#         "OPTIONS": {
#             "CLIENT_CLASS": "django_redis.client.DefaultClient",
#         }
#     }
# }

# # Tell select2 which cache configuration to use:
# SELECT2_CACHE_BACKEND = "select2"

MIDDLEWARE = (
    'django.middleware.security.SecurityMiddleware',
    'django.contrib.sessions.middleware.SessionMiddleware',
    'django.middleware.common.CommonMiddleware',
    'django.middleware.csrf.CsrfViewMiddleware',
    'django.contrib.auth.middleware.AuthenticationMiddleware',
    'django.contrib.messages.middleware.MessageMiddleware',
    #'django.middleware.clickjacking.XFrameOptionsMiddleware',
    'microsip_api.comun.middleware.CustomerMiddleware',
    # 'django.contrib.sessions.middleware.SessionMiddleware',
    # 'django.middleware.common.CommonMiddleware',
    # 'django.middleware.csrf.CsrfViewMiddleware',
    # 'django.contrib.auth.middleware.AuthenticationMiddleware',
    # 'django.contrib.messages.middleware.MessageMiddleware',
    # 'django.middleware.cache.CacheMiddleware',
    # 'django.middleware.transaction.TransactionMiddleware',
    # 'django.middleware.cache.FetchFromCacheMiddleware',
    #'minidetector2.Middleware',
    
    # Uncomment the next line for simple clickjacking protection:
    # 'django.middleware.clickjacking.XFrameOptionsMiddleware',
)

# Python dotted path to the WSGI application used by Django's runserver.
WSGI_APPLICATION = 'django_microsip_base.wsgi.application'

# List of callables that know how to import templates from various sources.
# TEMPLATE_LOADERS = (
#     'django.template.loaders.filesystem.Loader',
#     'django.template.loaders.app_directories.Loader',
#     'django.template.loaders.eggs.Loader',
# )
# TEMPLATE_DIRS = (
#     # Put strings here, like "/home/html/django_templates" or "C:/www/django/templates".
#     # Always use forward slashes, even on Windows.
#     # Don't forget to use absolute paths, not relative paths.
#     (BASE_DIR + '/templates'),
# )

# TEMPLATE_CONTEXT_PROCESSORS = (

# )
TEMPLATES = [
    {
        'BACKEND': 'django.template.backends.django.DjangoTemplates',
        'DIRS': [
            # insert your TEMPLATE_DIRS here
            (BASE_DIR + '/templates'),
        ],
        'OPTIONS': {
            'context_processors': [
                # Insert your TEMPLATE_CONTEXT_PROCESSORS here or use this
                # list if you haven't customized them:
                # 'django.contrib.auth.context_processors.auth',
                # 'django.core.context_processors.debug',
                # 'django.core.context_processors.i18n',
                'django.template.context_processors.media',
                'django.template.context_processors.static',
                'django.template.context_processors.request',
                # 'django.contrib.messages.context_processors.messages',
                'django_microsip_base.context_processors.menu',
                'django.template.context_processors.debug',
                'django.template.context_processors.request',
                'django.contrib.auth.context_processors.auth',
                'django.contrib.messages.context_processors.messages',
            ],
            'loaders': [
                # insert your TEMPLATE_LOADERS here
                'django.template.loaders.filesystem.Loader',
                'django.template.loaders.app_directories.Loader',
                # 'django.template.loaders.eggs.Loader',
            ]
        },
    },
]


# A sample logging configuration. The only tangible logging
# performed by this configuration is to send an email to
# the site admins on every HTTP 500 error when DEBUG=False.
# See http://docs.djangoproject.com/en/dev/topics/logging for
# more details on how to customize your logging configuration.
LOGGING = {
    'version': 1,
    'disable_existing_loggers': False,
    'filters': {
        'require_debug_false': {
            '()': 'django.utils.log.RequireDebugFalse'
        }
    },
    'handlers': {
        'mail_admins': {
            'level': 'ERROR',
            'filters': ['require_debug_false'],
            'class': 'django.utils.log.AdminEmailHandler'
        }
    },
    'loggers': {
        'django.request': {
            'handlers': ['mail_admins'],
            'level': 'ERROR',
            'propagate': True,
        },
    }
}

#Configuraciones para enviar mensajes usando gmail
EMAIL_USE_TLS = True
EMAIL_HOST = 'smtp.gmail.com'
EMAIL_HOST_USER = 'remitente@gmail.com'
EMAIL_HOST_PASSWORD = 'clavedelcorreo'
EMAIL_PORT = 587



class MainRouter(object):
    """
    A router to control all database operations on models.
    """
    def db_for_read(self, model, **hints):
        if model._meta.app_label == 'config':
            from microsip_api.comun.middleware import my_local_global
            return '%02d-CONFIG'% my_local_global.conexion_activa
        elif model._meta.app_label == 'auth':
            return 'default'
        elif model._meta.app_label == 'django':
            return 'default'
        elif model._meta.app_label == 'models_base':

            from microsip_api.comun.middleware import my_local_global
            if my_local_global.conexion_activa != None  and my_local_global.database_name != None:
                return '%02d-%s'% (my_local_global.conexion_activa ,my_local_global.database_name)

        return None

    def db_for_write(self, model, **hints):
        """
        Attempts to write auth models go to auth_db.
        """
        if model._meta.app_label == 'config':
            from microsip_api.comun.middleware import my_local_global
            return '%02d-CONFIG'% my_local_global.conexion_activa
        if model._meta.app_label == 'metadatos':
            from microsip_api.comun.middleware import my_local_global
            return '%02d-METADATOS'% my_local_global.conexion_activa
        elif model._meta.app_label == 'auth':
            return 'default'
        elif model._meta.app_label == 'django':
            return 'default'
        elif model._meta.app_label == 'models_base':
            from microsip_api.comun.middleware import my_local_global
            return '%02d-%s'% (my_local_global.conexion_activa ,my_local_global.database_name)

        return None

    def allow_relation(self, obj1, obj2, **hints):
        """
        Allow relations if a model in the auth app is involved.
        """
        if obj1._meta.app_label  == obj2._meta.app_label:
           return True
        if (obj1._meta.app_label  == 'auth' and obj2._meta.app_label == 'django') or (obj1._meta.app_label  == 'django' and obj2._meta.app_label == 'auth'):
           return True           
        elif (obj1._meta.app_label == 'models_base' and obj2._meta.app_label == 'models_base'):
            return True
        return False

    def allow_syncdb(self, db, model):
        """
        Make sure the auth app only appears in the 'auth_db'
        database.
        """
        
        if model._meta.app_label == 'config' or 'CONFIG' in db:
            return False
        if model._meta.app_label == 'metadatos' or 'METADATOS' in db:
            return False
        elif model._meta.app_label == 'auth' and db != 'default':
            return False
        elif model._meta.app_label == 'django' and db != 'default':
            return False
        elif db == 'default' and model._meta.app_label == 'models_base':
            return False
        else:
            return True

        return None